/*
 * OT_ids.h
 *
 */

#ifndef __OT_IDS_H__
#define __OT_IDS_H__

/* OT ID definitions (as supported by toon)  */

#define ID_STATUS_MASTER_SLAVE     0
#define ID_BOILER_CTRL_SETPOINT    1
#define ID_CONFIG_MASTER           2
#define ID_CONFIG_SLAVE            3
#define ID_FAULT_FLAGS             5
#define ID_REMOTE_PAR_FLAGS        6
#define ID_REMOTE_OVERRIDE         9
#define ID_MAX_MODULATION_LVL     14 /* not mode-set originally */
#define ID_MAX_BOILER_POWER       15
#define ID_ROOM_TEMP_SETPOINT     16

#define ID_REL_MODULATION_LVL     17
#define ID_BOILER_WATER_PRESS     18
#define ID_ROOM_TEMP              24
#define ID_BOILER_WATER_TEMP      25
#define ID_DHW_TEMP               26
#define ID_OUTSIDE_TEMP           27
#define ID_RETURN_WATER_TEMP      28
#define ID_SOLAR_STORAGE_TEMP     29 /* not mode-set, originally */
#define ID_BOILER_FAN_SPEED       35
#define ID_DHW_TEMP_BOUNDARIES    48
     
#define ID_MAX_DHW_SETPOINT       56
#define ID_MAX_CH_WATER_SETPOINT  57
#define ID_OEM_CODE_VENTILATION   73
#define ID_FAILED_BURNER_STARTS  113      
#define ID_LOW_FLAME_SIGNALS     114     
#define ID_OEM_DIAG_CODE         115     
#define ID_BURNER_STARTS         116
#define ID_CH_PUMP_STARTS        117
#define ID_DHW_PUMP_STARTS       118
#define ID_DHW_BURNER_STARTS     119

#define ID_BURNER_HOURS          120
#define ID_CH_PUMP_HOURS         121
#define ID_DHW_PUMP_HOURS        122
#define ID_DHW_BURNER_HOURS      123
#define ID_SLAVE_NUMBER_TYPE     127

/* OT ID types */

#define ID_TYPE_UNKNOWN            0
#define ID_TYPE_FLAGS              1
#define ID_TYPE_FLOAT              2
#define ID_TYPE_SIGNED_CHAR        3
#define ID_TYPE_UNSIGNED_CHAR      4
#define ID_TYPE_FLAGS_UCHAR        5
#define ID_TYPE_UNSIGNED_SHORT     6

/* ID flags */

/* ID0 */

#define FLAG_FAULT                 0x0001
#define FLAG_CH_ACTIVE             0x0002
#define FLAG_DHW_ACTIVE            0x0004
#define FLAG_FLAME_ON              0x0008
#define FLAG_COOLING_ACTIVE        0x0010
#define FLAG_CH2_ACTIVE            0x0020
#define FLAG_DIAG_EVENT            0x0040
#define FLAG_RESERVED_0_7          0x0080

#define FLAG_CH_ENABLED            0x0100
#define FLAG_DHW_ENABLED           0x0200
#define FLAG_COOLING_ENABLED       0x0400
#define FLAG_OTC_ACTIVE            0x0800
#define FLAG_CH2_ENABLED           0x1000
#define FLAG_RESERVED_0_13         0x2000
#define FLAG_RESERVED_0_14         0x4000
#define FLAG_RESERVED_0_15         0x8000

/* ID3 */

#define FLAG_HAVE_DHW              0x0100
#define FLAG_CTRL_BANG_BANG        0x0200
#define FLAG_HAVE_COOLING          0x0400
#define FLAG_HAVE_DHW_BUFFER       0x0800
#define FLAG_NO_PUMP_CTRL          0x1000
#define FLAG_HAVE_CH2              0x2000

/* ID5 */

#define FLAG_SERVICE_REQUEST       0x0100
#define FLAG_LOCKOUT_RESET         0x0200
#define FLAG_LOW_WATER_PRESS       0x0400
#define FLAG_FLAME_FAULT           0x0800
#define FLAG_AIR_PRESS_FAULT       0x1000
#define FLAG_WATER_OVER_TEMP       0x2000

/* ID6 */

#define FLAG_DHW_SETPOINT_RW       0x0001
#define FLAG_CH_SETPOINT_RW        0x0002

#define FLAG_DHW_SETPOINT_ENABLED  0x0100
#define FLAG_CH_SETPOINT_ENABLED   0x0200

/* ID100 */

#define FLAG_ROOM_T_MAN_OVERRIDE   0x0001
#define FLAG_ROOM_T_PROG_OVERRIDE  0x0002


#endif
